@@ -1,4 +1,4 @@
-count.overplot<-function(x,y,tol=NULL,col=par("fg"),pch=1,...) {
+count.overplot<-function(x,y,tol=NULL,col=par("fg"),pch="1",...) {
  if(missing(x)) stop("Usage: count.overplot(x,y,tol=NULL,...)")
  dimx<-dim(x)
  if(missing(y)) {
@@ -23,7 +23,7 @@ count.overplot<-function(x,y,tol=NULL,col=par("fg"),pch=1,...) {
  xlen<-length(x)
  if(xlen != length(y)) stop("x and y must be the same length.")
  if(is.null(tol)) {
-  plot(x,y,type="n",axes=FALSE,xlab="",ylab="")
+  if(dev.cur() == 1 ) plot(x,y,type="n",axes=FALSE,xlab="",ylab="")
   tol<-c(strwidth("o")/2,strheight("o")/2)
  }
  else {
@@ -56,5 +56,5 @@ count.overplot<-function(x,y,tol=NULL,col=par("fg"),pch=1,...) {
  }
  plot(xsep[1:nsep],ysep[1:nsep],xlim=xlim,ylim=ylim,
   col=sepcol[1:nsep],pch=seppch[1:nsep],...)
- text(xdup[1:ndup],ydup[1:ndup],xydup[1:ndup])
+ text(xdup[1:ndup],ydup[1:ndup],xydup[1:ndup],...)
 }
